pm4py.algo.conformance.alignments.petri\_net package
====================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.alignments.petri_net.utils
   pm4py.algo.conformance.alignments.petri_net.variants

Submodules
----------

pm4py.algo.conformance.alignments.petri\_net.algorithm module
-------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.petri_net
   :members:
   :undoc-members:
   :show-inheritance:
